==> wasabiD-0.2.92.tgz: package/Base/Layout/Modal.jsx <==
//create by wangzy
//date:2016-03-22
//desc:模态窗口
require("../../sass/Base/Layout/Modal.scss");
require("../../sass/Base/Button/button.scss");
var React =require("react");
var Button=require("../Button/Button.jsx");
var Resize=require("../Layout/Resize.jsx");
var Modal=React.createClass({
    propTypes: {
        width: React.PropTypes.number,
        height: React.PropTypes.number,
        fit:React.PropTypes.bool,
        visible: React.PropTypes.bool,
        closedHandler: React.PropTypes.func,
        showOK: React.PropTypes.bool,
        showCancel:React.PropTypes.bool,
        OKHandler: React.PropTypes.func,
        cancelHandler:React.PropTypes.func,
        timeout:React.PropTypes.number,
        resize:React.PropTypes.bool,
    },
    getDefaultProps:function() {
       return{
           width:730,//宽度
           height:500,//高度
           fit:false,//是否占全屏
           visible:false,//是否可见,
           modal:true,//默认没有遮罩层
           showOK:false,//是否显示确定按钮
           showCancel:false,//是否显示取消按钮
           OKHandler:null,//确定按钮的事件,
           timeout:null,//自动消失时间
       }
    },
    getInitialState:function() {
        return {
            visible:this.props.visible,
            width:this.props.width,
            height:this.props.height,
            left:(window.screen.width-this.props.width)/2,
            top:50,
            oldLeft:(window.screen.width-this.props.width)/2,
            oldTop:50,
            moveX:null,
            moveY:null,
        }
    },
    componentWillReceiveProps:function(nextProps) {
        this.setState({
                visible: nextProps.visible,
               width:nextProps.width,
            height:nextProps.height
            }
        );

    },
    componentDidMount:function()
    {

        this.timeout();

    },
    timeout:function()
    {

        if(this.props.timeout!=null) {
            setTimeout(()=> {
                this.setState({
                    visible: false
                })

            }, this.props.timeout)
        }
    },
    closeHandler:function() {//关闭事件
        this.setState({visible:false});
        if(this.props.closedHandler!=null)
        {
            this.props.closedHandler();
        }
    },
    openHandler:function() {//打开事件
        this.setState({visible:true});
    },
    mouseMoveHandler:function(event) {
        if(this.state.moveX!=null&&event.target.className=="alog-modal-header")
        {
            this.setState({
                left:this.state.oldLeft+event.clientX-this.state.moveX,
                top:this.state.oldTop+event.clientY-this.state.moveY,
            })
        }


    },
    mouseDownHandler:function(event) {
        this.setState({
            moveX:event.clientX,
            moveY:event.clientY,
        })
    },
    mouseOutHandler:function(event) {
        this.setState({
            moveX:null,
            moveY:null,
            oldLeft:this.state.left,
            oldTop:this.state.top
        })
    },
    mouseUpHandler:function(event) {
        this.setState({
            moveX:null,
            moveY:null,
            oldLeft:this.state.left,
            oldTop:this.state.top
        })
    },
    OKHandler:function()
    {
        if(this.props.OKHandler!=null)
        {
            this.props.OKHandler();
        }
        this.closeHandler();//关闭
    },
    cancelHandler:function()
    {
        if(this.props.cancelHandler!=null)
        {
            this.props.cancelHandler();
        }
        this.closeHandler();//关闭
    },
    render:function() {
        let activename="alog-modal-container ";
        if(this.state.visible==true)
        {
            activename="alog-modal-container active";
        }

        var width=this.state.width;
        var height=this.state.height;
        let left =this.state.left;
        let top=this.state.top;
        let control;
        let footer=null;
        let buttons=[];
        if(this.props.showOK==true||this.props.showCancel==true) {
            if(this.props.showOK)
            {
                buttons.push(
                    <Button title="确定" key="ok" onClick={this.OKHandler} style={{width:60,height:30}}></Button>
                )
            }
            if(this.props.showCancel)
            {
                buttons.push(
                    <Button title="取消" key="cancel" onClick={this.cancelHandler} style={{width:60,height:30,backgroundColor:"gray"}}></Button>
                )
            }
            footer=<div className="alog-modal-footer">
                {
                    buttons
                }
            </div>;
        }

        if(this.props.fit==true)
        {
            control= <div style={{backgroundColor:"white", display:this.state.visible==true?"block":"none",width:window.screen.availWidth-2,height:window.screen.availHeight-90,position:"absolute",zIndex:999999,left:0,top:0}} >
               <div className="alog-modal-header"> {this.props.title}</div><a className="alog-modal-close" onClick={this.closeHandler}></a>
                <div className="alog-modal-content" >
                    {
                        this.props.children
                    }
                 </div>
                {
                    footer
                }
        </div>
        }
        else {
            control=  <div className={activename}>
                <div className="active alog-overlay" style={{display:this.props.modal==true?"block":"none"}}></div>
                <Resize width={width} height={height} left={left} top={top}
                        width={width} height={height}
                        className="alog-modal fadein" resize={this.props.resize}>
                    <a  className="alog-modal-close" onClick={this.closeHandler}></a>
                    <div className="alog-modal-header" ref="header" onMouseMove={this.mouseMoveHandler}
                         onMouseDown={this.mouseDownHandler}
                         onMouseUp={this.mouseUpHandler}
                         onMouseOut={this.mouseOutHandler}
                    >{this.props.title}</div>

                    <div className="alog-modal-content" style={{height:(this.props.fit==true?"90%":this.state.height-40)}} >
                        {
                            this.props.children
                        }
                    </div>
                    {
                        footer
                    }
                </Resize>
            </div>
        }
            return(
                <div> {control}</div>

            )


    }
});


module.exports = Modal;

==> wasabiD-0.2.983.tgz: package/Base/Layout/Modal.jsx <==
//create by wangzy
//date:2016-03-22
//desc:模态窗口
require("../../sass/Base/Layout/Modal.scss");
require("../../sass/Base/Buttons/button.scss");
var React =require("react");
var Button=require("../Buttons/Button.jsx");
var Resize=require("../Layout/Resize.jsx");
var Modal=React.createClass({
    propTypes: {
        width: React.PropTypes.number,
        height: React.PropTypes.number,
        fit:React.PropTypes.bool,
        visible: React.PropTypes.bool,
        closedHandler: React.PropTypes.func,
        showOK: React.PropTypes.bool,
        showCancel:React.PropTypes.bool,
        OKHandler: React.PropTypes.func,
        cancelHandler:React.PropTypes.func,
        timeout:React.PropTypes.number,
        resize:React.PropTypes.bool,
    },
    getDefaultProps:function() {
       return{
           width:730,//宽度
           height:500,//高度
           fit:false,//是否占全屏
           visible:false,//是否可见,
           modal:true,//默认没有遮罩层
           showOK:false,//是否显示确定按钮
           showCancel:false,//是否显示取消按钮
           OKHandler:null,//确定按钮的事件,
           timeout:null,//自动消失时间
       }
    },
    getInitialState:function() {
        return {
            visible:this.props.visible,
            width:this.props.width,
            height:this.props.height,
            left:(window.screen.width-this.props.width)/2,
            top:50,
            oldLeft:(window.screen.width-this.props.width)/2,
            oldTop:50,
            moveX:null,
            moveY:null,
        }
    },
    componentWillReceiveProps:function(nextProps) {
        this.setState({
                visible: nextProps.visible,
               width:nextProps.width,
            height:nextProps.height
            }
        );

    },
    componentDidMount:function()
    {

        this.timeout();

    },
    timeout:function()
    {

        if(this.props.timeout!=null) {
            setTimeout(()=> {
                this.setState({
                    visible: false
                })

            }, this.props.timeout)
        }
    },
    closeHandler:function() {//关闭事件
        this.setState({visible:false});
        if(this.props.closedHandler!=null)
        {
            this.props.closedHandler();
        }
    },
    openHandler:function() {//打开事件
        this.setState({visible:true});
    },
    mouseMoveHandler:function(event) {
        if(this.state.moveX!=null&&event.target.className=="alog-modal-header")
        {
            this.setState({
                left:this.state.oldLeft+event.clientX-this.state.moveX,
                top:this.state.oldTop+event.clientY-this.state.moveY,
            })
        }


    },
    mouseDownHandler:function(event) {
        this.setState({
            moveX:event.clientX,
            moveY:event.clientY,
        })
    },
    mouseOutHandler:function(event) {
        this.setState({
            moveX:null,
            moveY:null,
            oldLeft:this.state.left,
            oldTop:this.state.top
        })
    },
    mouseUpHandler:function(event) {
        this.setState({
            moveX:null,
            moveY:null,
            oldLeft:this.state.left,
            oldTop:this.state.top
        })
    },
    OKHandler:function()
    {
        if(this.props.OKHandler!=null)
        {
            this.props.OKHandler();
        }
        this.closeHandler();//关闭
    },
    cancelHandler:function()
    {
        if(this.props.cancelHandler!=null)
        {
            this.props.cancelHandler();
        }
        this.closeHandler();//关闭
    },
    render:function() {
        let activename="alog-modal-container ";
        if(this.state.visible==true)
        {
            activename="alog-modal-container active";
        }

        var width=this.state.width;
        var height=this.state.height;
        let left =this.state.left;
        let top=this.state.top;
        let control;
        let footer=null;
        let buttons=[];
        if(this.props.showOK==true||this.props.showCancel==true) {
            if(this.props.showOK)
            {
                buttons.push(
                    <Button title="确定" key="ok" onClick={this.OKHandler} style={{width:60,height:30}}></Button>
                )
            }
            if(this.props.showCancel)
            {
                buttons.push(
                    <Button title="取消" key="cancel" onClick={this.cancelHandler} style={{width:60,height:30,backgroundColor:"gray"}}></Button>
                )
            }
            footer=<div className="alog-modal-footer">
                {
                    buttons
                }
            </div>;
        }

        if(this.props.fit==true)
        {
            control= <div style={{backgroundColor:"white", display:this.state.visible==true?"block":"none",width:window.screen.availWidth-2,height:window.screen.availHeight-90,position:"absolute",zIndex:999999,left:0,top:0}} >
               <div className="alog-modal-header"> {this.props.title}</div><a className="alog-modal-close" onClick={this.closeHandler}></a>
                <div className="alog-modal-content" >
                    {
                        this.props.children
                    }
                 </div>
                {
                    footer
                }
        </div>
        }
        else {
            control=  <div className={activename}>
                <div className="active alog-overlay" style={{display:this.props.modal==true?"block":"none"}}></div>
                <Resize width={width} height={height} left={left} top={top}
                        width={width} height={height}
                        className="alog-modal fadein" resize={this.props.resize}>
                    <a  className="alog-modal-close" onClick={this.closeHandler}></a>
                    <div className="alog-modal-header" ref="header" onMouseMove={this.mouseMoveHandler}
                         onMouseDown={this.mouseDownHandler}
                         onMouseUp={this.mouseUpHandler}
                         onMouseOut={this.mouseOutHandler}
                    >{this.props.title}</div>

                    <div className="alog-modal-content" style={{height:(this.props.fit==true?"90%":this.state.height-40)}} >
                        {
                            this.props.children
                        }
                    </div>
                    {
                        footer
                    }
                </Resize>
            </div>
        }
            return(
                <div> {control}</div>

            )


    }
});


module.exports = Modal;
